@@ -33,6 +33,7 @@ import six
 from blazarclient import client as blazar_client
 from blazarclient import exception
 from blazarclient import utils
+from blazarclient.v1.shell_commands import floatingips
 from blazarclient.v1.shell_commands import hosts
 from blazarclient.v1.shell_commands import leases
 from blazarclient import version as base_version
@@ -47,7 +48,11 @@ COMMANDS_V1 = {
     'host-show': hosts.ShowHost,
     'host-create': hosts.CreateHost,
     'host-update': hosts.UpdateHost,
-    'host-delete': hosts.DeleteHost
+    'host-delete': hosts.DeleteHost,
+    'floatingip-list': floatingips.ListFloatingIPs,
+    'floatingip-show': floatingips.ShowFloatingIP,
+    'floatingip-create': floatingips.CreateFloatingIP,
+    'floatingip-delete': floatingips.DeleteFloatingIP,
 }
 
 VERSION = 1
@@ -458,7 +463,8 @@ class BlazarShell(app.App):
             self.options.os_reservation_api_version,
             session=sess,
             service_type=self.options.service_type,
-            interface=self.options.endpoint_type
+            interface=self.options.endpoint_type,
+            region_name=self.options.os_region_name,
         )
         return
 
@@ -511,7 +517,7 @@ class BlazarShell(app.App):
 
 def main(argv=sys.argv[1:]):
     try:
-        return BlazarShell().run(map(encodeutils.safe_decode, argv))
+        return BlazarShell().run(list(map(encodeutils.safe_decode, argv)))
     except exception.BlazarClientException:
         return 1
     except Exception as e:
