@@ -16,8 +16,6 @@
 
 import mock
 
-from keystoneauth1 import adapter
-
 from blazarclient import base
 from blazarclient import exception
 from blazarclient import tests
@@ -130,6 +128,36 @@ class RequestManagerTestCase(tests.TestCase):
                           self.manager.request, url, "POST", **kwargs)
 
 
+class SessionClientTestCase(tests.TestCase):
+
+    def setUp(self):
+        super(SessionClientTestCase, self).setUp()
+        self.manager = base.SessionClient(user_agent="python-blazarclient",
+                                          session=mock.MagicMock())
+
+    @mock.patch('blazarclient.base.adapter.LegacyJsonAdapter.request')
+    def test_request_ok(self, m):
+        mock_resp = mock.Mock()
+        mock_resp.status_code = 200
+        mock_body = {"resp_key": "resp_value"}
+        m.return_value = (mock_resp, mock_body)
+        url = '/leases'
+        kwargs = {"body": {"req_key": "req_value"}}
+        resp, body = self.manager.request(url, "POST", **kwargs)
+        self.assertEqual((resp, body), (mock_resp, mock_body))
+
+    @mock.patch('blazarclient.base.adapter.LegacyJsonAdapter.request')
+    def test_request_fail(self, m):
+        resp = mock.Mock()
+        resp.status_code = 400
+        body = {"error message": "error"}
+        m.return_value = (resp, body)
+        url = '/leases'
+        kwargs = {"body": {"req_key": "req_value"}}
+        self.assertRaises(exception.BlazarClientException,
+                          self.manager.request, url, "POST", **kwargs)
+
+
 class BaseClientManagerTestCase(tests.TestCase):
 
     def setUp(self):
@@ -145,7 +173,7 @@ class BaseClientManagerTestCase(tests.TestCase):
                                          auth_token=None,
                                          session=self.session)
         self.assertIsInstance(manager.request_manager,
-                              adapter.LegacyJsonAdapter)
+                              base.SessionClient)
 
     def test_init_with_url_and_token(self):
         manager = base.BaseClientManager(blazar_url=self.blazar_url,
@@ -155,7 +183,7 @@ class BaseClientManagerTestCase(tests.TestCase):
                               base.RequestManager)
 
     def test_init_with_insufficient_info(self):
-        self.assertRaises(exception.InsufficientAuthInfomation,
+        self.assertRaises(exception.InsufficientAuthInformation,
                           base.BaseClientManager,
                           blazar_url=None,
                           auth_token=self.auth_token,
